教程和示例
===========

这里包含了详细的Jupyter notebook教程，帮助您快速上手使用CANNs库。

.. toctree::
   :maxdepth: 2
   :caption: 教程列表:

   01_quick_start
   00_design_philosophy

基础教程
--------

目前我们提供以下中文笔记本：

1. **快速开始** (:doc:`01_quick_start`)
   - 模块概览与关键职责
   - 各子系统的速查摘要
2. **设计哲学** (:doc:`00_design_philosophy`)
   - 模块结构与职责概览
   - 模型、任务、分析器、训练器与流水线的设计准则
   - 详细的扩展建议

## 开始学习

建议先阅读 **快速开始** 获取整体脉络，再深入 **设计哲学** 与示例代码。

每个教程都包含可运行的代码示例和详细说明。

## 交互式运行

您可以通过以下方式运行这些教程：

- **Binder**: 点击每个笔记本顶部的Binder徽章
- **Google Colab**: 点击Colab徽章在线运行
- **本地运行**: 下载并在Jupyter中打开
